package data

import (
	"context"

	"github.com/go-kratos/kratos/v2/log"

	"demo/internal/biz"
)

type adRepo struct {
	data *Data
	log  *log.Helper
}

func NewAdRepo(data *Data, logger log.Logger) biz.AdRepo {
	return &adRepo{
		data: data,
		log:  log.NewHelper(logger),
	}
}

func (p *adRepo) List(ctx context.Context, customerId int64, req *biz.ListReportRequest) (int64, biz.AdList, error) {
	db := p.data.db.Table("ads_report_advertise_hour").
		Select("advertise_id as ad_id,advertise_name as ad_name, campaign_id, campaign_name, advertiser_id, date_long AS stat_datetime, cost, `show`, click, `convert`, "+
			"deep_convert, attribution_convert, attribution_deep_convert, download_start, download_finish, click_install, "+
			"install_finish, active, register, next_day_open, next_day_open_cost, next_day_open_rate, attribution_next_day_open_cnt,"+
			" game_addiction, pay_count, in_app_uv, in_app_detail_uv, in_app_cart, in_app_pay, in_app_order, attribution_game_pay_7d_count,"+
			" game_pay_count, total_play, valid_play, play_25_feed_break, play_50_feed_break, play_75_feed_break, play_100_feed_break, "+
			"play_duration_sum, attribution_active_pay_intra_one_day_count, attribution_active_pay_intra_one_day_amount, gmt_modified AS timestamp").
		Where("customer_id = ?", customerId).
		Where("is_delete = ?", 0)

	// add start_date and end_date condition
	if req.StartDate != "" {
		db = db.Where("date_long >= ?", req.StartDateLong)
	}
	if req.EndDate != "" {
		db = db.Where("date_long <= ?", req.EndDateLong)
	}

	var total int64
	if err := db.Count(&total).Error; err != nil {
		return 0, nil, err
	}
	var list biz.AdList
	if err := db.Order(req.GetOrderBy("id") + " " + req.GetOrderByMode()).
		Limit(req.Limit()).Offset(req.Offset()).Scan(&list).Error; err != nil {
		return total, nil, err
	}
	return total, list, nil
}
